<?php
namespace KERN23\ContentDesigner\Hooks;

/**
 * Class/Function which manipulates the rendering of item example content and replaces it.
 *
 */
class DrawItem implements \TYPO3\CMS\Backend\View\PageLayoutViewDrawItemHookInterface {

	private $cObj;
	protected $tsSetup;
	
	/**
	 * Preprocesses the preview rendering of a content element.
	 *
	 * @param	tx_cms_layout	$parentObject:  Calling parent object
	 * @param	boolean         $drawItem:      Whether to draw the item using the default functionalities
	 * @param	string	        $headerContent: Header content
	 * @param	string	        $itemContent:   Item content
	 * @param	array			$row:           Record row of tt_content
	 * @return	void
	 */
	public function preProcess(\TYPO3\CMS\Backend\View\PageLayoutView &$parentObject, &$drawItem, &$headerContent, &$itemContent, array &$row) {
		$expr = '/^tx_contentdesigner_(.*)$/si';
		
		if ( preg_match($expr,$row['CType'],$match) ) {
			// Load the TypoScript Config
			$config         = array('row' => &$row);
			$arr_list        = \KERN23\ContentDesigner\Utility\TypoScript::loadConfig($config, 'tx_contentdesigner', $row['pid']);
			$this->tsSetup  = $arr_list[$row['CType'].'.'];
			unset($arr_list,$config);
			
			if ( $this->tsSetup['settings.']['disableDefaultDrawItem'] == 1 ) {
				$drawItem = false;
			}
			
			$this->getContentElementPreview($match[1],$row,$headerContent,$itemContent);
		}
	}
 
	/**
	 * Preview of a content element *_pi1.
	 */
	private function getContentElementPreview($tscType,&$row,&$headerContent,&$itemContent) {
		// Load the Field Configuration for the current selected Object
		if ( is_array($this->tsSetup['settings.']['previewObj.']) ) {
			$objType    = $this->tsSetup['settings.']['previewObj'];
			$objArray   = $this->tsSetup['settings.']['previewObj.'];
			
			$CTypeTitle = $this->tsSetup['settings.']['title'];
			
			$conf       = $this->tsSetup['settings.'];
		} else return false;
		
		// Flexform rendern
		$ffh = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('TYPO3\\CMS\\Extbase\\Service\\FlexFormService'); # Static call not axcepted in 6.1.1
		$flexFormData = $ffh->convertFlexFormContentToArray($row['pi_flexform']);
		
		// Flex Data laden
		$cObjAr = array();
		if ( is_array($conf['cObject.']) && sizeof($conf['cObject.']) > 0 ) {
			// TS cObject als Daten Zuweisungsvorlage nehmen
			foreach ( array_keys($conf['cObject.']) as $sheet ) {
				$sheet = substr($sheet,0,strlen($sheet)-1);
				foreach ( array_keys($conf['cObject.'][$sheet.'.']['el.']) as $fieldKey ) {
					$fieldKey = substr($fieldKey,0,strlen($fieldKey)-1);
					$cObjAr[$fieldKey] = $flexFormData['settings']['flexform'][$fieldKey];
				}
			}
			
		} elseif ( isset($conf['cObjectFlexFile']) ) {
			// Load Flexfile
			$flexDefinition = \TYPO3\CMS\Core\Utility\GeneralUtility::xml2array(file_get_contents(\TYPO3\CMS\Core\Utility\GeneralUtility::getFileAbsFileName($conf['cObjectFlexFile'])));
			
			// Flexform Datei als Daten Zuweisungsvorlage nehmen
			if ( is_array($flexDefinition) && sizeof($flexDefinition) > 0 ) {
				foreach ( $flexDefinition['sheets'] as $sheet ) {
					foreach ( array_keys($sheet['ROOT']['el']) as $fieldKey ) {
						if ( preg_match("/^settings\.flexform\.(.*[^\.])$/i",$fieldKey,$m) ) {
							$cObjAr[$m[1]] = $flexFormData['settings']['flexform'][$m[1]];
						} elseif ( preg_match("/^settings\.(.*[^\.])$/i",$fieldKey,$m) ) {
							$cObjAr[$m[1]] = $flexFormData['settings'][$m[1]];
						} else $cObjAr[$fieldKey] = $flexFormData[$fieldKey];
					}
				}
			}
		}
		
		// initialize TSFE
		$cObj = \KERN23\ContentDesigner\Utility\TypoScript::cObjInit();
		
		// TypoScript FIELD Startpoint setzen
		$cObj->start(array_merge($row,$cObjAr));
		
		// Ausfuehren
		$itemContent = \KERN23\ContentDesigner\Utility\TypoScript::parseTypoScriptObj($objType,$objArray,$cObj);
		$cObj->start($data,'tt_content'); // Reset des CURRENT Wert damit die Content ID wieder eingefuegt werden kann
	}
}

?>
